<?php
// Global variables define
define('LEO_PARENT_TEMPLATE_DIR_URI', get_template_directory_uri());
define('LEO_TEMPLATE_DIR_URI', get_stylesheet_directory_uri());
define('LEO_TEMPLATE_DIR', trailingslashit(get_stylesheet_directory()));

if (!function_exists('wp_body_open')) {

    function wp_body_open() {
        /**
         * Triggered after the opening <body> tag.
         */
        do_action('wp_body_open');
    }

}

//enqueue default.css
add_action('wp_enqueue_scripts', 'leo_theme_css', 999);

function leo_theme_css() {
    wp_enqueue_style('leo-parent-style', LEO_PARENT_TEMPLATE_DIR_URI . '/style.css');
    wp_enqueue_style('leo-parent-media-style', LEO_PARENT_TEMPLATE_DIR_URI . '/css/media-responsive.css');
    wp_enqueue_style('bootstrap', LEO_PARENT_TEMPLATE_DIR_URI . '/css/bootstrap.css');
    wp_dequeue_style('wallstreet-default', LEO_PARENT_TEMPLATE_DIR_URI . '/css/default.css');
    wp_enqueue_style('leo-default', LEO_TEMPLATE_DIR_URI . '/css/default.css');
    //add script
    wp_enqueue_script('leo-mp-masonry-js', LEO_TEMPLATE_DIR_URI . '/js/masonry/mp.mansory.min.js');
}

add_action('after_setup_theme', 'leo_theme_setup');

function leo_theme_setup() {
    load_child_theme_textdomain('leo', LEO_TEMPLATE_DIR . '/languages');
    require( LEO_TEMPLATE_DIR . '/functions/customizer/customizer-copyright.php' );
    require( LEO_TEMPLATE_DIR . '/functions/customizer/customizer-header-layout.php' );
    require( LEO_TEMPLATE_DIR . '/functions/customizer/customizer-blog-layout.php' );
    require( LEO_TEMPLATE_DIR . '/functions/template-tag.php' );

    //About Theme
    $theme = wp_get_theme(); // gets the current theme
    if ('Leo' == $theme->name) {
        if (is_admin()) {
            require LEO_TEMPLATE_DIR . '/admin/admin-init.php';
        }
    }

    add_theme_support( 'automatic-feed-links' );

    add_theme_support( 'title-tag' );
}

//Set for old user
if (!get_option('wallstreet_user', false)) {
    //detect old user and set value
    $leo_user = get_option('wallstreet_pro_options', array());
    if ((isset($leo_user['service_title']) || isset($leo_user['service_description']) || isset($leo_user['home_blog_heading']) || isset($leo_user['home_blog_description']))) {
        add_option('wallstreet_user', 'old');
    } else {
        add_option('wallstreet_user', 'new');
    }
}

//Set theme Default data
function leo_theme_data_setup() {
    $leo_current_options = wp_parse_args(get_option('wallstreet_pro_options', array()), wallstreet_theme_data_setup());
//print_r($header_setting);
    if (get_option('wallstreet_user', 'new') == 'old' || $leo_current_options['upload_image_logo'] != '' || $leo_current_options['webrit_custom_css'] == 'nomorenow') {

        $array_new = array(
            'header_classic_layout_setting' => 'default',
            'service_slide_layout_setting' => 'default',
            'blog_masonry3_layout_setting' => 'default',
        );
    } else {
        $array_new = array(
            'header_classic_layout_setting' => 'classic',
            'service_slide_layout_setting' => 'slide',
            'blog_masonry3_layout_setting' => 'masonry3',
        );
    }
    $array_old = array(
        'footer_copyright' => '<p>' . __('<a href="https://wordpress.org">Proudly powered by WordPress</a> | Theme: <a href="https://webriti.com" rel="nofollow"> Leo</a> by Webriti', 'leo') . '</p>',
        'footer_social_media_enabled' => false,
        'social_media_twitter_link' => "",
        'social_media_facebook_link' => "",
        'social_media_linkedin_link' => "",
        'social_media_youtube_link' => "",
        'social_media_instagram_link' => '',
    );

    return $result = array_merge($array_new, $array_old);
}

// Add masonry blog layout
add_action('wp_footer', 'leo_custom_script');

function leo_custom_script() {

    wp_reset_query();
    $col = 4;
    ?>
    <script>
        jQuery(document).ready(function (jQuery) {
            jQuery("#blog-masonry").mpmansory(
                    {
                        childrenClass: 'masonry-item', // default is a div
                        columnClasses: 'padding', //add classes to items
                        breakpoints: {
                            lg: 4, //Change masonry column here like 2, 3, 4 column
                            md: 6,
                            sm: 6,
                            xs: 12
                        },
                        distributeBy: {order: false, height: false, attr: 'data-order', attrOrder: 'asc'}, //default distribute by order, options => order: true/false, height: true/false, attr => 'data-order', attrOrder=> 'asc'/'desc'
                        onload: function (items) {
                            //make somthing with items
                        }
                    }
            );
        });
    </script>
    <?php

}

//Add Header Text style
if (!function_exists('leo_header_text_style')) :
    add_action('wp_head', 'leo_header_text_style');

    function leo_header_text_style() {
        $leo_options = wp_parse_args(get_option('wallstreet_pro_options', array()), leo_theme_data_setup());
        if ($leo_options['header_classic_layout_setting'] == 'classic') {
            ?>
            <style type="text/css">
                .navbar-header .wallstreet_title_head, .navbar-header .site-description {
                    color: #2a2c33!important;
                }

                .home-blog-section {
                    padding: 70px 0 0px;
                }
                .homepage_mycarousel {
                    /*margin-bottom: 70px;*/
                }
            </style>
            <?php

        }
    }

 
endif;


/* sidebar */
add_action('widgets_init', 'leo_widgets_init');

function leo_widgets_init() {
  
    register_sidebar(array(
        'name' => esc_html__('Footer widget area', 'leo'),
        'id' => 'footer-widget-area',
        'description' => esc_html__('Footer widget area', 'leo'),
        'before_widget' => '<div class="col-md-3 col-sm-6 footer_widget_column">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="footer_widget_title">',
        'after_title' => '</h2>',
    ));

}
